@@ -20,6 +20,8 @@ from drivelib import __version__ as drivelib_version
 from drivelib import GoogleDrive
 from .google_remote import GoogleRemote
 from . import __version__
+from . import _default_client_id as DEFAULT_CLIENT_ID
+from . import _default_client_secret as DEFAULT_CLIENT_SECRET
 
 class bcolors:
     HEADER = '\033[95m'
@@ -61,16 +63,16 @@ def setup():
         use_own_api = False
 
     if use_own_api:
-        client_id = input("Client ID: ")
-        client_secret = input("Client Secret: ")
+        client_id = input("Client ID: ").strip()
+        client_secret = input("Client Secret: ").strip()
     else:
         print("======")
         print("IMPORTANT: Google has started to lockdown their Google Drive API. This might affect access to your remotes.")
         print("Until this is settled you'll see a warning about this application not being verified by Google which you need to accept in order to proceed.")
         print("Read more on https://github.com/Lykos153/git-annex-remote-googledrive#google-drive-api-lockdown")
         print("======")
-        client_id = '275666578511-ndjt6mkns3vgb60cbo7csrjn6mbh8gbf.apps.googleusercontent.com'
-        client_secret = 'Den2tu08pRU4s5KeCp5whas_'
+        client_id = DEFAULT_CLIENT_ID
+        client_secret = DEFAULT_CLIENT_SECRET
 
 
     gauth = {
@@ -141,4 +143,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
